# Text Rank

##

[![PyPi Version](https://img.shields.io/pypi/v/text-rank)](https://pypi.org/project/text-rank/)

[![Actions Status](https://github.com/blester125/text-rank/workflows/Unit%20Test/badge.svg)](https://github.com/blester125/text-rank/actions)

Implementation of text rank algorithms described in [(Mihalcea and Tarau, 2004)](http://www.aclweb.org/anthology/W04-3252)
